<?php
/* $Id: estonian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/*
 * Translated by Marko Ellermaa, <marko.ellermaa@nlkp.net>
 * Previous translations by Alvar Soome <finsoft@users.sourceforge.net>
 *
 * March 2006: Several changes and fixes done (by Marko Ellermaa)
 */

$charset = 'iso-8859-1';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ph', 'Esm', 'Tei', 'Kol', 'Nel', 'Ree', 'Lau');
$month = array('Jan', 'Veb', 'Mr', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Det');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y kell %H:%M:%S';
$timespanfmt = '%s peva, %s tundi, %s minutit ja %s sekundit';

$strAbortedClients = 'Katkestatud';
$strAccessDeniedCreateConfig = 'Arvatav phjus on te pole veel loonud seadete faili. Soovitavalt vid kasutada %1$ssetup script%2$s et seadistada.';
$strAccessDeniedExplanation = 'phpMyAdmin proovis henduda MySQL serveriga ja server lkkas henduse tagasi. Te peaksite kontrollima serverit, kasutajanime ja parooli config.inc.php failis ning kontrollima, et need vastaks infole mis te saite oma MySQL serveri administraatori kest.';
$strAccessDenied = 'Ligips keelatud';
$strAction = 'Tegevus';
$strAddAutoIncrement = 'Lisa AUTO_INCREMENT vrtus';
$strAddClause = 'Lisa %s';  
$strAddConstraints = 'Lisa piirangud';
$strAddDeleteColumn = 'Lisa/Kustuta vlja veerud';
$strAddDeleteRow = 'Lisa/Kustuta kriteeriumirida';
$strAddFields = 'Lisa %s vli(jad)';
$strAddHeaderComment = 'Lisa vaba kommentaar pisesse (\\n eraldab read)';
$strAddIntoComments = 'Lisa kommentaaridesse';
$strAddNewField = 'Lisa uus vli';
$strAddPrivilegesOnDb = 'Lisa privileegid antud andmebaasile';
$strAddPrivilegesOnTbl = 'Lisa privileegid antud tabelile';
$strAddSearchConditions = 'Lisa otsinguparameetrid ("WHERE" lause sisu):';
$strAddToIndex = 'Lisa indeksisse &nbsp;%s&nbsp;rida/read';
$strAddUser = 'Lisa uus kasutaja';
$strAddUserMessage = 'Te lisasite uue kasutaja.';
$strAdministration = 'Administreerimine';
$strAffectedRows = 'Mjutatud read:';
$strAfterInsertBack = 'Mine eelmisele lehele tagasi';
$strAfterInsertNewInsert = 'Lisa jrgmine uus rida';
$strAfterInsertNext = 'Muuda jrgmist rida';
$strAfterInsertSame = 'Mine tagasi sellele lehele';
$strAfter = 'Peale %s';
$strAll = 'Kik';
$strAllowInterrupt = 'Luba katkestada Import juhul kui skript leiab et ajalimiit on letamisel. See vib olla hea viis suurte failide importimisel, kuigi vib katkestada lekanded.';
$strAllTableSameWidth = 'kuva kik tabelid sama laiusega?';
$strAlterOrderBy = 'Muuda tabeli sorteeringut';
$strAnalyzeTable = 'Analsi tabelit';
$strAnd = 'ja';
$strAndThen = 'ja siis';
$strAngularLinks = 'Nurgelised lingid'; 
$strAnIndex = 'Indeks lisati %s';
$strAnyHost = 'Kik masinad';
$strAny = 'kik';
$strAnyUser = 'Kik kasutajad';
$strApproximateCount = 'Vib olla umbkaudne. Vaadake FAQ 3.11';
$strAPrimaryKey = 'Primaarne vti lisati %s';
$strArabic = 'Araabia';
$strArmenian = 'Armeenia';
$strAscending = 'Kasvav';
$strAtBeginningOfTable = 'Tabeli algusesse';
$strAtEndOfTable = 'Tabeli lppu';
$strAttr = 'Parameetrid';
$strAutodetect = 'Automaatne tuvastus';
$strAutomaticLayout = 'Automaatne vljund';

$strBack = 'Tagasi';
$strBaltic = 'Balti';
$strBeginCut = 'ALUSTA LIGET';
$strBeginRaw = 'ALUSTA PUHAST';
$strBinary = 'Binaarne';
$strBinaryDoNotEdit = 'Binaarne - rge muutke';
$strBinaryLog = 'Binaarne logi';
$strBinLogEventType = 'Sndmuse tp';
$strBinLogInfo = 'Informatsioon';
$strBinLogName = 'Logi nimi';
$strBinLogOriginalPosition = 'Originaal positioon';
$strBinLogPosition = 'Positsioon';
$strBinLogServerId = 'Serveri ID';
$strBookmarkAllUsers = 'Anna kikidele kasutajatele juurdeps sellele jrjehodjale';
$strBookmarkCreated = 'Jrjehoidja %s loodud';
$strBookmarkDeleted = 'Jrjehodja kustutati.';
$strBookmarkLabel = 'Nimetus';
$strBookmarkQuery = 'Jrjehodjaga SQL pring';
$strBookmarkReplace = 'Kirjuta samanimeline jrjehoidja le';
$strBookmarkThis = 'Lisa see SQL pring jrjehoidjasse';
$strBookmarkView = 'Vaata ainult';
$strBrowseDistinctValues = 'Sirvi erinevaid vrtusi';
$strBrowseForeignValues = 'Vaata vliseid vrtuseid';
$strBrowse = 'Vaata';
$strBufferPoolActivity = 'Puhverdusala aktiivsus';
$strBufferPool = 'Puhverdusala';
$strBufferPoolUsage = 'Puhverdusala kasutamine';
$strBufferReadMissesInPercent = 'Lugemis vigasid %';
$strBufferReadMisses = 'Lugemis vigasid';
$strBufferWriteWaitsInPercent = 'Kirjutamine ootab %';
$strBufferWriteWaits = 'Kirjutamine ootab';
$strBulgarian = 'Bulgaaria';
$strBusyPages = 'Hivatud lehed';
$strBzError = 'phpMyAdmin ei suutnud pakkida seda andmebaasivljundit kuna Bz2 moodul on vigane selles PHP versioonis. Me soovitame tungivalt oma phpMyAdmini konfiguratsioonifailis panna lipu <code>$cfg[\'BZipDump\']</code> vrtuseks <code>FALSE</code>. Kui te soovite kasutada Bz2 pakkimist peaksite te oma PHP versiooni uuendama viimasele versioonile. Lugege PHP vea %s raportit tpsemaks infoks.';
$strBzip = '"bzipitud"';

$strCalendar = 'Kalender';
$strCancel = 'Katkesta'; 
$strCanNotLoadExportPlugins = 'Viga eksportimis moodulite laadimisel, palun kontrolli seadeid!';
$strCanNotLoadImportPlugins = 'Pole vimalik Importida mooduleid (plugins), palun kontrolli seadeid!';
$strCannotLogin = 'Ei suuda MySQL serverisse logida';
$strCantLoad = 'ei suutnud lugeda moodulit %s,<br />palun kontrollige PHP konfiguratsiooni';
$strCantLoadRecodeIconv = 'Ei suuda lugeda iconv vi recode moodulit mida on vaja thetabeli konvertimiseks, konfigureerige PHP-d nii, et see sisaldaks antud mooduleid vi keelake thetabeli konvertimine phpMyAdminis.';
$strCantRenameIdxToPrimary = 'Ei suuda muuta indeksit PRIMAARSEKS!';
$strCantUseRecodeIconv = 'Ei suuda kasutada iconv-d vi libiconvi vi recode_string funktsiooni kuigi moodul on installitud Kontrollige oma PHP konfiguratsiooni.';
$strCardinality = 'Kasulikkus';
$strCaseInsensitive = 'tstutundetu';
$strCaseSensitive = 'tstutundlik';
$strCentralEuropean = 'Kesk-Euroopa';
$strChangeCopyModeCopy = '... hoia vana alles.';
$strChangeCopyModeDeleteAndReload = ' ... kustuta vana kasutajate tabelist ja taaslae privileegid prast seda.';
$strChangeCopyModeJustDelete = ' ... kustuta vana kasutajate tabelist.';
$strChangeCopyMode = 'Loo uus kasutaja samade privileegidega ja ...';
$strChangeCopyModeRevoke = ' ... kanna kik aktiivsed privileegid le vanast ja kustuta see prast.';
$strChangeCopyUser = 'Vaheta logimisinformatsiooni / Kopeeri kasutaja';
$strChangeDisplay = 'Vali vli mida kuvada';
$strChange = 'Muuda';
$strChangePassword = 'Muuda parooli';
$strCharsetOfFile = 'Faili thetabel:';
$strCharsetsAndCollations = 'Thetabelid ja mrangud';
$strCharsets = 'Thetabelid';
$strCharset = 'Thetabel';
$strCheckAll = 'Mrgista kik';
$strCheckOverhead = 'Kontrolli lekulusid';
$strCheckPrivs = 'Kontrollige privileege';
$strCheckPrivsLong = 'Kontrolli privileege andmebaasile &quot;%s&quot;.';
$strCheckTable = 'Kontrolli tabelit';
$strChoosePage = 'Palun valige leht muutmiseks';
$strColComFeat = 'Nitan veeru kommentaare';
$strCollation = 'Mrang';
$strColumnNames = 'Vljade nimed';
$strColumnPrivileges = 'Vli-spetsiifilised privileegid';
$strCommand = 'Ksk';
$strCommentsForTable = 'KOMMENTAARID TABELILE';
$strComments = 'Kommentaarid';
$strCompatibleHashing = 'MySQL&nbsp;4.0-iga hilduv';
$strCompleteInserts = 'Tispikk INSERT';
$strCompression = 'Pakkimine';
$strCompressionWillBeDetected = 'Imporditava faili pakkimise meetod leitakse automaatselt: %s';
$strConfigDefaultFileError = 'Pole vimalik laadida vaikimisi seadete faili: "%1$s"';
$strConfigFileError = 'phpMyAdmin ei suutnud lugeda Teie konfiguratsioonifaili!<br />See vib juhtuda kui PHP leiab vea selles vi PHP ei leia antud faili les.<br />Palun kutsuge konfiguratsioonifail vlja otseselt kasutades linki allpool ja lugege PHP veateadet(eid) mis teile eldakse. Enamustel juhtudel on kuskilt puudu lakoma vi semikoolon.<br />Kui Teile kuvatakse thi leht on kik korras.';
$strConfigureTableCoord = 'Palun seadke koordinaadid tabelile %s';
$strConnectionError = 'Ei saa hendust: vigased seaded.';
$strConnections = 'hendused';
$strConstraintsForDumped = 'Piirangud salvestatud tabelitele';
$strConstraintsForTable = 'Piirangud tabelile';
$strCookiesRequired = 'Kpsised(cookies) peavad alates sellest momendist lubatud olema.';
$strCopyDatabaseOK = 'Andmebaas %s on kopeeritud %s';
$strCopy = 'Kopeeri';
$strCopyTable = 'Kopeeri tabel (andmebaas<b>.</b>tabel):';
$strCopyTableOK = 'Tabel %s on kopeeritud andmebaasi %s.';
$strCopyTableSameNames = 'Ei saa tabelit iseendasse kopeerida!';
$strCouldNotKill = 'phpMyAdmin ei suutnud katkestada protsessi %s. Tenoliselt on see juba suletud.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE enne kopeerimist';
$strCreateIndex = 'Loo indeks &nbsp;%s&nbsp;vljadest';
$strCreateIndexTopic = 'Loo uus indeks';
$strCreate = 'Loo';
$strCreateNewDatabase = 'Loo uus andmebaas';
$strCreateNewTable = 'Loo uus tabel andmebaasi %s';
$strCreatePage = 'Loo uus leht';
$strCreatePdfFeat = 'PDF-ide tegemine';
$strCreateRelation = 'Suhte loomine (relation)';  
$strCreateTable  = 'Loo tabel';
$strCreateUserDatabase = 'Andmebaas kasutajale';  
$strCreateUserDatabaseName = 'Loo sama nimega andmebaas ja anna kik igused'; 
$strCreateUserDatabaseNone = 'Puudub';  
$strCreateUserDatabaseWildcard = 'Anna kik igused Metanimele (username\_%)';
$strCreationDates = 'Loo/muuda/kontrolli kuupevi';
$strCriteria = 'Kriteerium';
$strCroatian = 'Horvaatia';
$strCSV = 'CSV';
$strCSVImportOptions = 'CSV seaded';
$strCSVOptions = 'CSV seaded';
$strCyrillic = 'Kirillitsa';
$strCzechSlovak = 'Tsehhi-Slovaki';
$strCzech = 'Tsehhi';

$strDanish = 'Taani';
$strData = 'Andmed';
$strDatabase = 'Andmebaas';
$strDatabaseEmpty = 'Andmebaasi nimi on thi!';
$strDatabaseExportOptions = 'Andmebaasi eksportimise seaded';
$strDatabaseHasBeenDropped = 'Andmebaas %s kustutatud.';
$strDatabaseNoTable = 'See andmebaas ei sisalda tabelit!';
$strDatabases = 'Andmebaasid';
$strDatabasesDropped = 'andmebaasid %s kustutati nnestunult.';
$strDatabasesStats = 'Andmebaaside statistika';
$strDatabasesStatsDisable = 'Keelake statistika';
$strDatabasesStatsEnable = 'Lubage statistika';
$strDatabasesStatsHeavyTraffic = 'Mrkus: Lubades siin andmebaasi statistika vite tekitada vga koormava liikuse webiserveri ja MySQL-i vahel.';
$strDataDict = 'Andmesnastik';
$strDataOnly = 'Ainult andmed';
$strDataPages = 'Lehed andmetega';
$strDBComment = 'Andmebaasi kommentaar: ';
$strDBCopy = 'Kopeeri andmebaas';
$strDbIsEmpty = 'Andmebaas tundub olevat thi!'; 
$strDbPrivileges = 'Andmebaas-spetsiifilised privileegid';
$strDBRename = 'Nimeta andmebaas mber';
$strDbSpecific = 'andmebaasiphine';
$strDefaultEngine = '%s on vaikimisi varundusmootor sellele MySQL serverile.';
$strDefault = 'Vaikimisi';
$strDefaultValueHelp = 'Vaikimisi vrtuse jaoks sisestage lihtsalt ksik vrtus, ilma kaldkriipsudega varjestamata ning jutumrkideta, kasutades jrgmist kirjakuju: a';
$strDefragment = 'Defrgamenteeri tabel';
$strDelayedInserts = 'Kasuta ajastatud lisamisi';
$strDeleteAndFlushDescr = 'See on parim tee, kuid privileegide taaslaadimine vib vtta aega.';
$strDeleteAndFlush = 'Kustutage kasutajad ja taaslaadige privileegid prast seda.';
$strDeleted = 'Rida kustutatud';
$strDeletedRows = 'Kustuta read:';
$strDelete = 'Kustuta';
$strDeleteNoUsersSelected = 'htegi kasutajat pole valitud kustutamiseks!';
$strDeleteRelation = 'Kustuta suhe';  
$strDeleting = 'Kustutan %s';
$strDelimiter = 'Eraldaja'; 
$strDelOld = 'Antud lehel on viiteid tabelitele mida enam ei ole. Kas te soovite kustutada need viited?';
$strDescending = 'Kahanev';
$strDescription = 'Kirjeldus';
$strDesigner = 'Kujundaja';
$strDictionary = 'snaraamat';
$strDirectLinks = 'Otselingid';  
$strDirtyPages = 'Mustad lehed';
$strDisabled = 'Keelatud';
$strDisableForeignChecks = 'Keela vrvtmete (foreign key) kontroll';
$strDisplayFeat = 'Kuva vimalused';
$strDisplayOrder = 'Nitamise jrjekord:';
$strDisplayPDF = 'Nita PDF skeemi';
$strDoAQuery = 'Tee "pring nite jrgi" (lhend: "%")';
$strDocSQL = 'DocSQL';  
$strDocSQLOptions = 'DocSQL valikud';  
$strDocu = 'Dokumentatsioon';
$strDoYouReally = 'Kas te testi tahate ';
$strDropDatabaseStrongWarning = 'Thelepanu! Te HVITATE kogu andmebaasi!';
$strDrop = 'Kustuta';
$strDropUsersDb = 'Kustuta andmebaasid millel on samad nimed nagu kasutajatel.';
$strDumpingData = 'Tabeli andmete salvestamine';
$strDumpSaved = 'Vljavte salvestati faili %s.';
$strDumpXRows = 'Pri %s rida alustades reast %s.';
$strDynamic = 'dnaamiline';

$strEdit = 'Muuda';
$strEditPDFPages = 'Muuda PDF lehti';
$strEditPrivileges = 'Muuda privileege';
$strEffective = 'Efektiivne';
$strEmptyResultSet = 'MySQL tagastas thja tulemuse (s.t. null rida).';
$strEmpty = 'Thjenda';
$strEnabled = 'Lubatud';
$strEncloseInTransaction = 'Lisa eksport lekandesse';
$strEndCut = 'LPETA LIGE';
$strEnd = 'Lpp';
$strEndRaw = 'LPETA PUHAS';
$strEngineAvailable = '%s on saadaval selles MySQL serveris.';
$strEngineDisabled = '%s on keelatud selles MySQL serveris.';
$strEngines = 'Mootor';
$strEngineUnsupported = 'See MySQL server ei toeta %s varundusmootorit.';
$strEnglish = 'Inglise';
$strEnglishPrivileges = ' Mrkus: MySQL privileegide nimed on ingliskeelsed ';
$strErrorInZipFile = 'Viga ZIP arhiivis:';
$strErrorRenamingTable = 'Viga tabeli nime %1$s muutimsel %2$s';  
$strError = 'Viga';
$strEscapeWildcards = 'Metamrgid _ ja % peaksid olema varjestatud mrgiga \, kui soovite neid sisestada';
$strEsperanto = 'Esperanto';
$strEstonian = 'Eesti';
$strExcelEdition = 'Exceli versioon';
$strExcelOptions = 'Excel\'i seaded';
$strExecuteBookmarked = 'Kivita salvestatud pring';
$strExplain = 'Seleta SQL-i';
$strExport = 'Ekspordi';
$strExportImportToScale = 'Ekspordi/Impordi skaala';
$strExportMustBeFile = 'Valitud eksportimise tp tuleb salvestada faili!';
$strExtendedInserts = 'Laiendatud lisamised';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Ebannestunud ritused';
$strFieldHasBeenDropped = 'Vli %s kustutatud';
$strFieldsEmpty = ' Vljade loetelu on thi! ';
$strFieldsEnclosedBy = 'Vljad mbritsetud';
$strFieldsEscapedBy = 'Vljad varjatud';
$strFieldsTerminatedBy = 'Vljad eraldatud';
$strFields = 'Vljade arv';
$strField = 'Vli';
$strFileAlreadyExists = 'Fail %s on juba serveris olemas, muutke faili nime vi kontrollige lekirjutamise seadeid.';
$strFileCouldNotBeRead = 'Faili ei suudetud lugeda';
$strFileNameTemplateDescriptionDatabase = 'andmebaasi nimi';
$strFileNameTemplateDescription = 'Seda vrtust on tlgendatud kasutades %1$sstrftime%2$s, sa vid kasutada sama aja(time) formaati. Lisaks tulevad ka jrgnevad muudatused: %3$s. lejnud teks jb nii nagu ta on.';
$strFileNameTemplateDescriptionServer = 'serveri nimi';
$strFileNameTemplateDescriptionTable = 'tabeli nimi';
$strFileNameTemplate = 'Faili nime template';
$strFileNameTemplateRemember = 'jta template meelde';
$strFileToImport = 'Imporditav Fail';
$strFixed = 'parandatud';
$strFlushPrivilegesNote = 'Mrkus: phpMyAdmin vtab kasutajate privileegid otse MySQL privileges tabelist. Tabeli sisu vib erineda sellest, mida server hetkel kasutab, seda juhul kui olete ksitsi muudatusi teinud. Sellisel juhul peaksite te privileegid %staaslaadima%s enne jtkamist.';
$strFlushQueryCache = 'Thjenda pringute vahemlu';
$strFlushTables = 'Thjenda (sulge) kik tabelid';
$strFlushTable = 'htlusta tabelid ("FLUSH")';
$strFontSize = 'Fondi suurus';
$strForeignKeyError = 'Viga luues vrvtit (foreign key) (kontrolli admetpe)';
$strFormat = 'Formaat';
$strFormEmpty = 'Puuduv vrtus vormis !';
$strFreePages = 'Vabad lehed';
$strFullText = 'Tistekstid';
$strFunction = 'Funktsioon';
$strFunctions = 'Funktsioonid';  

$strGenBy = 'Genereerija ';
$strGeneralRelationFeat = 'Peamised seoste vimalused';
$strGenerate = 'Genereeri';
$strGeneratePassword = 'Genereeri parool';
$strGenTime = 'Tegemisaeg';
$strGeorgian = 'Gruusia';
$strGerman = 'Saksa';
$strGlobal = 'globaalne';
$strGlobalPrivileges = 'Globaalsed privileegid';
$strGlobalValue = 'ldine vrtus';
$strGo = 'Mine';
$strGrantOption = 'igused';
$strGreek = 'Kreeka';
$strGzip = '"gzipitud"';

$strHandler = 'Ttleja';
$strHasBeenAltered = 'on muudetud.';
$strHasBeenCreated = 'on loodud.';
$strHaveToShow = 'Te peate valima vhemalt he veeru kuvamiseks';
$strHebrew = 'Heebrea';
$strHelp = 'Abi';  
$strHexForBinary = 'Kasuta 16nd koodi binaarvljades';
$strHide         = 'Peida';
$strHideShowAll = 'Peida/Nita kik';
$strHideShowNoRelation = 'Peida/Nita tabelid millel puudub suhe'; 
$strHome = 'Esileht';
$strHomepageOfficial = 'Ametlik phpMyAdmini koduleht';
$strHostEmpty = 'Masin on thi!';
$strHost = 'Masin';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 ekspordi seaded';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 ekspordi seaded';
$strHungarian = 'Ungari';

$strIcelandic = 'Islandi';
$strId = 'ID';
$strIdxFulltext = 'Tistekst';
$strIgnoreDuplicates = 'Ignoreeri korduvaid ridasid';
$strIgnore = 'Ignoreeri';
$strIgnoreInserts = 'Kasutaja ignoreeritavaid lisamisi';
$strImportExportCoords = 'Impordi/Ekspordi kordinaadid PDF skeemile';
$strImportFiles = 'Importige failid';
$strImportFormat = 'Imporditud faili formaat';
$strImport = 'Import';
$strImportSuccessfullyFinished = 'Import lppetati edukalt, %d pringut kivitatud.';
$strIndexes = 'Indeksid';
$strIndexHasBeenDropped = 'Indeks %s kustutatud';
$strIndex = 'Indeks';
$strIndexName = 'Indeksi nimi&nbsp;:';
$strIndexType = 'Indeksi tp&nbsp;:';
$strIndexWarningMultiple = 'Rohkem kui ks %s vti loodi vljale `%s`';
$strIndexWarningPrimary = 'PRIMARY ja INDEX vtmed ei tohiks mlemad olla mratud vljale `%s`';
$strIndexWarningTable = 'Probleemid tabeli `%s` indeksitega';
$strIndexWarningUnique = 'UNIQUE ja INDEX ei tohiks mlemad olla mratud vljale `%s`';
$strInnoDBAutoextendIncrement = 'Automaatne suurenduse laiendus';
$strInnoDBAutoextendIncrementDesc = ' Automaatselt suurenev suurus mis lisatakse automaatselt suurenevale tabeliruumile kui see titub.';
$strInnoDBBufferPoolSizeDesc = 'Mlupuhvri suurus mida InnoDB kasutab oma andmete ja indeksite puhverdamiseks.';
$strInnoDBBufferPoolSize = 'Puhverdusala suurus';
$strInnoDBDataFilePath = 'Andmefailid';
$strInnoDBDataHomeDir = 'Andmete kodukataloog';
$strInnoDBDataHomeDirDesc = 'hine kataloogi nimeosa kigi InnoDB andmefailide jaoks.';
$strInnoDBPages = 'lehti';
$strInnoDBRelationAdded = 'InnoDB suhe lisatud';
$strInnodbStat = 'InnoDB staatus';
$strInsecureMySQL = 'Teie konfiguratsioonifail sisaldab seadeid (root kasutaja ilma paroolita) mis vastab MySQL-i vaikimisi priviligeeritud kasutajale. Kui Teie MySQL-i server jookseb sellise seadega on ta avatud rnnakutele, soovitav on see turvaauk kiiresti parandada.';
$strInsertAsNewRow = 'Lisa uue reana';
$strInsertedRowId = 'Lisatud rea id:';
$strInsertedRows = 'Lisatud read:';
$strInsert = 'Lisa';
$strInternalNotNecessary = '* Sisene seos ei ole vajalik kui ta eksisteerib ka InnoDB-s.';
$strInternalRelationAdded = 'Sisemine suhe loodud'; 
$strInternalRelations = 'Sisesed seosed';
$strInUse = 'kasutusel';
$strInvalidAuthMethod = 'Vigane autoriseerimise meetod konfiguratsioonifailis:';
$strInvalidColumnCount = 'Veergude arv peab olema nullist suurem.';
$strInvalidColumn = 'Vigased vlja veerud (%s) valitud!';
$strInvalidCSVFieldCount = 'Vigane vljade arv CSV sisendis real %d.';
$strInvalidCSVFormat = 'Vigane formaat CSV sisendis real %d.';
$strInvalidCSVParameter = 'Vigane parameeter CSV importimisel: %s';
$strInvalidDatabase = 'Vigane andmebaas';  
$strInvalidFieldAddCount = 'Peate lisama vhemalt he vlja.';
$strInvalidFieldCount = 'Tabelil peab olema vhemalt ks vli.';
$strInvalidLDIImport = 'See plugin ei toeta pakitud importe!';
$strInvalidRowNumber = '%d ei ole ige reanumber.';
$strInvalidServerHostname = 'Vigane hostname serverile %1$s. Palun kontrolli seadeid.';
$strInvalidServerIndex = 'Vigane serveri indeks: "%s"';
$strInvalidTableName = 'Vigane tabeli nimi'; 

$strJapanese = 'Jaapani';
$strJoins = 'Liited';
$strJumpToDB = 'Hppa andmebaasile &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Kustutatud&quot; kasutajad vivad ikka veel ligi pseda serverile, kuni privileegid pole uuesti sisse loetud.';
$strJustDelete = 'Lihtsalt kustutage kasutajad privilege tabelist.';

$strKeepPass = 'rge muutke parooli';
$strKeyCache = 'Vtme vahemlu';
$strKeyname = 'Vtme nimi';
$strKill = 'Tapa';
$strKnownExternalBug = 'See %s funktionaalsus on mjutatud tuntud viga, vaata %s';
$strKorean = 'Korea';

$strLandscape = 'Laipilt';
$strLanguageFileNotFound = 'Ei leia keele fail "%1$s" .';
$strLanguage = 'Keel';  
$strLanguageUnknown = 'Tundmatu keel: %1$s.';
$strLatchedPages = 'Lukustatud lehed';
$strLatexCaption = 'Tabeli seletus';
$strLatexContent = 'Tabeli __TABLE__ sisu';
$strLatexContinuedCaption = 'Jtkuva tabeli seletus';
$strLatexContinued = '(jtkub)';
$strLatexIncludeCaption = 'Lisa tabeli seletus';
$strLatexLabel = 'Nimetuse vti';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX\'i seaded';
$strLatexStructure = 'Tabeli __TABLE__ struktuur';
$strLatvian = 'Lti';
$strLDI = 'CSV kasutades LOAD DATA';
$strLDIImportOptions = 'Seaded CSV impordiks kasutades LOAD DATA';
$strLDILocal = 'kasuta LOCAL vtmesna';
$strLengthSet = 'Pikkus/Vrtused*';
$strLimitNumRows = 'Ridade arv lehel';
$strLinesTerminatedBy = 'Read lpetatud';
$strLinkNotFound = 'Linki ei leitud';
$strLinksTo = 'Lingib ';
$strLithuanian = 'Leedu';
$strLocalhost = 'Lokaalne';
$strLocationTextfile = 'tekstifaili asukoht';
$strLoginInformation = 'Logimise informatsioon';
$strLogin = 'Sisselogimine';
$strLogout = 'Logi vlja';
$strLogPassword = 'Parool:';
$strLogServer = 'Server';
$strLogUsername = 'Kasutajanimi:';
$strLongOperation = 'See tegevus vib vtta kaua aega. Jtkan?';

$strMaxConnects = 'maks. parallel hendusi';
$strMaximalQueryLength = 'Loodud pringu maksimaalne pikkus';
$strMaximumSize = 'Maksimaalne suurus: %s%s';
$strMbExtensionMissing = 'Ei leitud mbstring PHP lisa ja tundub, et te kasutate mitmebaidilist thetabelit. Ilma mbstring lisata ei suuda phpMyAdmin poolitada teksti korrektselt ja tulemus vib olla ootustele mittevastav.';
$strMbOverloadWarning = 'Te olete lubanud mbstring.func_overload oma PHP konfiguratsioonis. See seade ei hildu phpMyAdminiga ja vib osade andmete kadumist phjustada!';
$strMIME_available_mime = 'Olemasolevad MIME-tbid';
$strMIME_available_transform = 'Available transformations';
$strMIME_description = 'Kirjeldus';
$strMIME_MIMEtype = 'MIME-tp';
$strMIME_nodescription = 'Selle transformatsiooni jaoks ei ole kirjeldust.<br />Palun ksige autorilt, mida %s teeb.';
$strMIME_transformation = 'Browseri transformatsioon';
$strMIME_transformation_note = 'Transformatsiooni vimaluste ja tema MIME-tbi transformatsiooni nimekirjaks vajutage %stransformatsiooni kirjeldusele%s';
$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud vrtused, kasutades jrgmist formaati: \'a\', 100, b,\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") vi lakoma ("\'") nende vrtuste seas, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
$strMIME_transformation_options = 'Transformeerimise seaded';
$strMIMETypesForTable = 'MIME TBID TABELILE';
$strMIME_without = 'MIME-tbid kursiivis ei oma eraldi transofrmatsiooni funktsiooni';
$strModifications = 'Muutused salvestatud';
$strModifyIndexTopic = 'Muuda indeksit';
$strModify = 'Muuda';
$strMoveMenu = 'Liiguta men';  
$strMoveTableOK = 'Tabel %s viidu le andmebaasi %s.';
$strMoveTableSameNames = 'Ei saa tabelit iseendasse liigutada!';
$strMoveTable = 'Vii tabel le (andmebaas<b>.</b>tabel):';
$strMultilingual = 'mitmekeelne';
$strMyISAMDataPointerSize = 'Andmeviida suurus';
$strMyISAMDataPointerSizeDesc = 'Vaikimisi viida suurus baitides, mida kasutatakse CREATE TABLE ksuga MyISAM tabelite jaoks kui MAX_ROWS seade on mramata.';
$strMyISAMMaxExtraSortFileSizeDesc = 'Kui ajutine fail mida kasutatakse kiire MyISAM indeksi loomiseks on suurem kui kasutada siin mratud vtmecache suurust, siis eelistage vtmecache meetodit.';
$strMyISAMMaxExtraSortFileSize = 'Maksimaalne failisuurus ajutiste failide jaoks indeksi genereerimisel';
$strMyISAMMaxSortFileSizeDesc = 'Maksimaalne failisuurus MySQL-i ajutise faili jaoks mida kasutatakse MyISAM indeksi uuesti genereerimiseks (REPAIR TABLE, ALTER TABLE vi LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maksimaalne suurus ajutiste sorteeringufailide jaoks';
$strMyISAMRecoverOptions = 'Automaatne taastamine';
$strMyISAMRecoverOptionsDesc = 'Automaatne taastamine purunenud MyISAM tabelitele, aktiveeritakse vtmega --myisam-recover serveri kivitamisel.';
$strMyISAMRepairThreadsDesc = 'Kui see vrtus on suurem kui 1 siis MyISAM tabeli indeksid luuakse paralleelselt (iga indeks oma limus) sorteerimise teel parandamise ajal.';
$strMyISAMRepairThreads = 'Paranda limud';
$strMyISAMSortBufferSizeDesc = 'Puhver mis hivatakse kui sorteeritakse MyISAM indekseid REPAIR TABLE ajal vi kui luuakse indekseid CREATE INDEX vi ALTER TABLE kskudega.';
$strMyISAMSortBufferSize = 'Sordi puhvri suurus';
$strMySQLCharset = 'MySQLi thetabel';
$strMysqlClientVersion = 'MySQL kliendi versioon';
$strMySQLConnectionCollation = 'MySQL henduse kollatsioon';
$strMySQLSaid = 'MySQL tles: ';
$strMySQLShowProcess = 'Nita protsesse';
$strMySQLShowStatus = 'Nita MySQL-i jooksvat informatsiooni';
$strMySQLShowVars = 'Nita MySQL ssteemseid muutujaid';

$strName = 'Nimi';
$strNext = 'Jrgmine';
$strNoActivity = 'Ebaaktiivne %s sekundit vi rohkem, palun sisenege uuesti';
$strNoDatabases = 'Pole andmebaase';
$strNoDatabasesSelected = 'htegi andmebaasi ei ole valitud.';
$strNoDataReceived = 'Andmeid ei saadud importimisel. Vimalik et faili nime ei saadetud, vi faili suurus letab maksimaalset suurust lubatud PHP seadetes. Vaata FAQ 1.16.';
$strNoDescription = 'pole kirjeldust';
$strNoDetailsForEngine = 'Detailne seisuinformatsioon antud varundusmootori kohta puudub.';
$strNoDropDatabases = '"DROP DATABASE" ksud keelatud.';
$strNo = 'Ei';
$strNoExplain = 'Jta SQL-i seletamine vahele';
$strNoFilesFoundInZip = 'Ei leidnud htegi faili ZIP arhiivist!';
$strNoFrames = 'phpMyAdmin on sbralikum <b>frame toetava</b> browseriga.';
$strNoIndex = 'Indeksit pole defineeritud!';
$strNoIndexPartsDefined = 'Indeksi osad pole defineeritud!';
$strNoModification = 'Ei muudetud';
$strNone = 'Pole';
$strNoOptions = 'Sellel formaadil pole seadeid';
$strNoPassword = 'Ilma paroolita';
$strNoPermission = 'Webiserver ei oma igusi , et salvestada fail %s.';
$strNoPhp = 'ilma PHP koodita';
$strNoPrivileges = 'Ei oma htegi privileegi';
$strNoRights = 'Teil pole piisavalt igusi, et hetkel siin olla!';
$strNoRowsSelected = 'Ridu pole valitud';
$strNoSpace = 'Liiga vhe kettaruumi, et salvestada fail %s.';
$strNoTablesFound = 'Andmebaasist ei leitud tabeleid.';
$strNoThemeSupport = 'Teemade tugi puudub, palun kontrollige oma seadeid ja/vi oma teemade kataloogi %s.';
$strNotNumber = 'See pole number!';
$strNotOK = 'Ei ole korras';
$strNotSet = '<b>%s</b> tabelit ei leitud vi ei eksisteeri %s';
$strNoUsersFound = 'Ei leitud htegi kasutajat.';
$strNoValidateSQL = 'Jta SQL-i kontroll vahele';
$strNull = 'Null';
$strNumberOfFields = 'Vljade arv';
$strNumberOfTables = 'Tabelite arv';
$strNumSearchResultsInTable = '%s vaste(t) tabelis <i>%s</i>';
$strNumSearchResultsTotal = '<b>Kokku:</b> <i>%s</i> vaste(t)';
$strNumTables = 'Tabelid';

$strOK = 'Korras';
$strOpenDocumentSpreadsheet = 'Ava dokumendi arvutustabel';
$strOpenDocumentSpreadsheetOptions = 'Ava dokumendi arvutustabeli seaded';
$strOpenDocumentText = 'Ava dokumendi tekst';  
$strOpenDocumentTextOptions = 'Ava dokumendi teksti seaded';
$strOpenNewWindow = 'Ava uus phpMyAdmin aken';
$strOperations = 'Tegevused';
$strOperator = 'Operaator';
$strOptimizeTable = 'Optimiseeri tabelit';
$strOr = 'vi';
$strOverhead = 'lejv';
$strOverwriteExisting = 'Kirjuta olemasolev(ad) fail(id) le';

$strPageNumber = 'Lehenumber:';
$strPagesToBeFlushed = 'Lehed htlustamiseks';
$strPaperSize = 'Paberi suurus';
$strPartialImport = 'Osaline import';
$strPartialText = 'Lhendatud tekstid';
$strPasswordChanged = 'Kasutaja %s parool vahetati nnestunult.';
$strPasswordEmpty = 'Parool on thi!';
$strPasswordHashing = 'Parooli trkimine';
$strPasswordNotSame = 'Paroolid ei hti!';
$strPassword = 'Parool';
$strPdfDbSchema = 'Andmebaasi "%s" skeem - leheklg %s';
$strPdfInvalidTblName = '"%s" tabel ei eksisteeri!';
$strPdfNoTables = 'Pole tabeleid';
$strPDFOptions = 'PDF seaded';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Genereerib aruande sisaldades andmeid ksikust tabelist)';
$strPDFReportTitle = 'Raporti pealkiri';
$strPerHour = 'tunni kohta';
$strPerMinute = 'minutis';
$strPerSecond = 'sekundis';
$strPersian = 'Prsia';
$strPhoneBook = 'telefoniraamat';
$strPHP40203 = 'Te kasutate PHP 4.2.3, milles on tsine viga mitmebaidiste tekstidega (mbstring). Vaadake PHP vearaportit 19404. Seda PHP versiooni ei soovitata kasutada phpMyAdminiga.';
$strPhp = 'Loo PHP kood';
$strPHPVersion = 'PHP versioon';
$strPleaseSelectPrimaryOrUniqueKey = 'Palun vali primaarne vi unkaalne vti'; 
$strPmaDocumentation = 'phpMyAdmini dokumentatsioon';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> konstant peab teie konfiguratsioonifailis mratud olema!';
$strPmaWiki = 'phpMyAdmin wiki';  
$strPolish = 'Poola';
$strPortrait = 'Portreepilt';
$strPos1 = 'Algus';
$strPrevious = 'Eelmine';
$strPrimaryKeyHasBeenDropped = 'Primaarne vti kustutatud';
$strPrimaryKeyName = 'Primaarse vtme nimi peab olema... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>peab</b> olema ja <b>ainult</b> olema primaarse vtme nimi!)';
$strPrimary = 'Primaarne';
$strPrint = 'Prindi';
$strPrintViewFull = 'Trkivaade (tispikkade tekstidega)';
$strPrintView = 'Trkivaade';
$strPrivDescAllPrivileges = 'Sisaldab kiki privileege peale GRANT.';
$strPrivDescAlter = 'Lubab muuta olemasolevate tabelite struktuure.';
$strPrivDescAlterRoutine = 'Lubabu salvestatud rutiinide muutmise ja kustutamise.';
$strPrivDescCreateDb = 'Lubab luua uusi andmebaase ja tabeleid.';
$strPrivDescCreateRoutine = 'Lubab salvestatud rutiinide loomise.';
$strPrivDescCreateTbl = 'Lubab luua uusi tabeleid.';
$strPrivDescCreateTmpTable = 'Lubab luua ajutisi tabeleid.';
$strPrivDescCreateUser = 'Lubab kasutajakontode loomise, kustutamise ja muutmise.';
$strPrivDescCreateView = 'Lubab uute vaadete loomist.';
$strPrivDescDelete = 'Lubab kustutada infot.';
$strPrivDescDropDb = 'Lubab kustuada andmebaase ja tabeleid.';
$strPrivDescDropTbl = 'Lubab kustutada tabeleid..';
$strPrivDescExecute5 = 'Lubab salvestatud rutiinide kivituse.';
$strPrivDescExecute = 'Lubab kivitada salvestatud protseduure; Ei oma mingit effekti antud MySQL versioonis.';
$strPrivDescFile = 'Lubab andmete eksportimist faili ja andmete importimist failidest.';
$strPrivDescGrant = 'Lubab lisada kasutajaid ja privileege ilma privileges tabelit taaskivitamata.';
$strPrivDescIndex = 'Lubab luua ja kustutada indekseid.';
$strPrivDescInsert = 'Lubab lisada ja muuta infot.';
$strPrivDescLockTables = 'Lubab lukustada tabeleid aktiivse pringu tarbeks.';
$strPrivDescMaxConnections = 'Limiteerib henduste arvu tunnis kasutaja jaoks.';
$strPrivDescMaxQuestions = 'Limiteerib pringute arvu tunnis kasutaja jaoks.';
$strPrivDescMaxUpdates = 'Limiteerib kskude, mis muudavad suvalist tabelit vi andmebaasi, arvu tunnis kasutaja jaoks';
$strPrivDescMaxUserConnections = 'Piirab henduste arvu mida kasutajal vib korraga olla.';
$strPrivDescProcess3 = 'Lubab tappa kasutajate protsesse.';
$strPrivDescProcess4 = 'Lubab vaadata tielikult pringuid protsessitabelis.';
$strPrivDescReferences = 'Ei oma antud MySQL versioonis mingit effekti.';
$strPrivDescReload = 'Lubab taaslaadida serveri seadmeid ja puhastada serveri cachet.';
$strPrivDescReplClient = 'Lubab kasutajal ksida kus on slaved/masterid.';
$strPrivDescReplSlave = 'Vajalik slavede paljundamiseks.';
$strPrivDescSelect = 'Lubab lugeda infot.';
$strPrivDescShowDb = 'Annab ligipsu kogu andmebaasilistingule.';
$strPrivDescShowView = 'Lubab SHOW CREATE VIEW pringute kivitamise.';
$strPrivDescShutdown = 'Lubab serverit maha lasta.';
$strPrivDescSuper = 'Lubab henduda, isegi kui maksimaalne henduste arv on saavutatud; Vajalik enamike administratiivsete operatsioonide jaoks, nagu globaalsete muutujate seadmine vi teiste kasutajate henduste tapmine.';
$strPrivDescUpdate = 'Lubab muuta infot.';
$strPrivDescUsage = 'Mitte htegi privileegi.';
$strPrivileges = 'Privileegid';
$strPrivilegesReloaded = 'Privileegid taaslaeti edukalt.';
$strProcedures = 'Toimingud';
$strProcesses = 'Protsessid';
$strProcesslist = 'Protsessinimekiri';
$strProtocolVersion = 'Protokolli versioon';
$strPutColNames = 'Pange vljade nimed esimesse ritta';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = 'Pring nite jrgi';
$strQueryCache = 'Pringute vahemlu';
$strQueryFrame = 'Pringuaken';
$strQueryOnDb = 'SQL-pring andmebaasist <b>%s</b>:';
$strQueryResultsOperations = 'Pringu tulemuste tegevused';
$strQuerySQLHistory = 'SQL-ajalugu';
$strQueryStatistics = '<b>Pringu statistika</b>: Alates stardist, %s pringut on saadetud serverile.';
$strQueryTime = 'Pring kestis %01.4f sek';
$strQueryType = 'Pringu tp';
$strQueryWindowLock = 'Antud pringut mitte muuta vljaspool akent.';

$strReadRequests = 'Prdumised lugemiseks';
$strReceived = 'Saadud';
$strRecommended = 'soovituslik';  
$strRecords = 'Kirjeid';
$strReferentialIntegrity = 'Kontrolli prinevust:';
$strRefresh = 'Uuenda';
$strRelationalSchema = 'Seoseskeem';
$strRelationDeleted = 'Suhe kustutatud'; 
$strRelationNotWorking = 'Lisavimalused ttamiseks lingitud tabelitega on deaktiveeritud. Et lugeda miks see nii on, vajutage %ssiia%s.';
$strRelationsForTable = 'SEOSED TABELILE';
$strRelations = 'Suhted';
$strRelationView = 'Prinevuse vaade';
$strReloadingThePrivileges = 'Taaslaen privileege';
$strReload = 'Lae uuesti';  
$strReloadPrivileges = 'Lae privileegid uuesti';
$strRemoveSelectedUsers = 'Eemalda valitud kasutajad';
$strRenameDatabaseOK = 'Andmebaas %s on mber nimetatud %s';
$strRenameTable = 'Nimeta tabel mber';
$strRenameTableOK = 'Tabel %s on mber nimetatud %s';
$strRepairTable = 'Paranda tabelit';
$strReplaceNULLBy = 'Asenda NULL ';
$strReplaceTable = 'Asenda tabeli andmed failiga';
$strReplication = 'Tiraeerimine';
$strReset = 'Thista';
$strResourceLimits = 'Ressursilimiidid';
$strReType = 'Sisesta uuesti';
$strRevokeAndDeleteDescr = 'Kasutajatel on ikka veel USAGE privileeg, kuni privileegid pole taaslaetud.';
$strRevokeAndDelete = 'Eemalda kik aktiivsed privileegid kasutajatelt ning kustuta nad prast seda.';
$strRevokeMessage = 'Te vtsite tagasi privileegid %s-lt';
$strRevoke = 'Vta tagasi';
$strRomanian = 'Rumeenia';
$strRowLength = 'Rea pikkus';
$strRowsFrom = 'read alates';
$strRowSize = ' rea suurus ';
$strRowsModeFlippedHorizontal = 'horisontaalne (pratud pis)';
$strRowsModeHorizontal = 'horisontaalselt';
$strRowsModeOptions = 'nita %s and korda pealkirju iga %s jrel';
$strRowsModeVertical = 'vertikaalselt';
$strRows = 'Ridu';
$strRowsStatistic = 'Rea statistika';
$strRunning = 'jookseb masinas %s';
$strRunQuery = 'Lae pring';
$strRunSQLQueryOnServer = 'Kivita SQL ksk/ksud Masinas %s';
$strRunSQLQuery = 'Pri SQL pring(uid) andmebaasist %s';
$strRussian = 'Vene';

$strSaveOnServer = 'Salvestage serverisse kataloogi %s';
$strSavePosition = 'Salvesta positsioon';  
$strSave = 'Salvesta';
$strScaleFactorSmall = 'Skalaarfaktor on liiga vike, et skeem mahuks hele lehele.';
$strSearchFormTitle = 'Otsi andmebaasist';
$strSearchInTables = 'Otsi tabeli(te)st:';
$strSearchNeedle = 'Sna(d) vi vrtus(ed) otsinguks (lhend: "%"):';
$strSearchOption1 = 'vhemalt ks snadest';
$strSearchOption2 = 'kik snadest';
$strSearchOption3 = 'tpne fraas';
$strSearchOption4 = 'regulaaravaldisena';
$strSearch = 'Otsi';
$strSearchResultsFor = 'Otsingu tulemused "<i>%s</i>" %s:';
$strSearchType = 'Leia:';
$strSecretRequired = 'Konfiguratsioonifail nuab nd salajast vtmesna (blowfish_secret).';
$strSelectADb = 'Valige andmebaas';
$strSelectAll = 'Mrgista kik';
$strSelectBinaryLog = 'Valige binaarne logi vaatamiseks';
$strSelectFields = 'Vali vljad (vhemalt ks):';
$strSelectForeignKey = 'Vali vrvti(Foreign Key)';  
$strSelectNumRows = 'pringus';
$strSelectReferencedKey = 'Vali eelistus vti (referenced key)';
$strSelectTables = 'Vali tabelid';
$strSend = 'Salvesta failina';
$strSent = 'Saadetud';
$strServerChoice = 'Serveri valik';
$strServerNotResponding = 'Server ei vasta';
$strServer = 'Server';
$strServers = 'Serverid';  
$strServerStatusDelayedInserts = 'Ajastatud lisamised';
$strServerStatus = 'Jooksev informatsioon';
$strServerStatusUptime = 'See MySQL server on kinud %s. Kivitusaeg %s.';
$strServerTabVariables = 'Muutujad';
$strServerTrafficNotes = '<b>Serveri liiklus</b>: Need tabelid nitavad vrguliikluse statistikat selle MySQL serveri jaoks alates tema kivitamisest.';
$strServerVars = 'Serveri muutujad ja seaded.';
$strServerVersion = 'Serveri versioon';
$strSessionValue = 'Sessiooni vrtus';
$strSetEnumVal = 'Kui vlja tp on "enum" vi "set", palun sisestage vrtused kasutades jrgmist paigutust: \'a\',\'b\',\'c\'...<br />Kui te peate lisama kaldkriipsu ("\") vi lakoma ("\'") sinna paigutusse, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
$strShowAll = 'Nita kiki';
$strShowColor = 'Nita vrvi';
$strShowDatadictAs = 'Andmesnastiku formaat';
$strShowFullQueries = 'Nita tispikkasid pringuid';
$strShowGrid = 'Nita vrgustiku';
$strShowHideLeftMenu = 'Nita/Peida vasak men';
$strShowingBookmark = 'Nitan jrjehoidjat';
$strShowingPhp = 'Nitan PHP koodina'; 
$strShowingRecords = 'Nita ridu';
$strShowingSQL = 'Nitan SQL pringut';  
$strShow = 'Nita';
$strShowOpenTables = 'Nita avatud tabeleid';
$strShowPHPInfo = 'Nita PHP informatsiooni';
$strShowSlaveHosts = 'Nita alluvaid(slave)';
$strShowSlaveStatus = 'Nita alluvate(slave) staatust';
$strShowStatusBinlog_cache_disk_useDescr = 'lekannete number mida kasutab ajutise binaar logi vahemlu kuid letab binlog_cache_size suurust ja kasutatakse ajutist faili et salvestada lekande Kske (pringuid).';
$strShowStatusBinlog_cache_useDescr = 'lekannete number mis kasutasid ajutist binaar logi vahemlu.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Ajutiste tabelite arv, loodud automaatselt serveri poolt, pringuid kivitades. Kui Created_tmp_disk_tables on suur, sa vid tahta suurendada tmp_table_size vrtust et olla mlul baseeruv mitte kettal.';
$strShowStatusCreated_tmp_filesDescr = 'Mitu ajutist faili mysqld on loonud.';
$strShowStatusCreated_tmp_tablesDescr = 'Ajutiste mlul baseeruvate tabelite arv, loodud automaatselt serveri poolt, pringuid kivitades.';
$strShowStatusDelayed_errorsDescr = 'Mitu rida on loodud ksuga INSERT DELAYED milles toimus viga (arvatavasti korduv vti).';
$strShowStatusDelayed_insert_threadsDescr = 'Mitu INSERT DELAYED ttleja (handler) limu on kasutuses. Iga erinev tabel mis kasutab INSERT DELAYED saab oma limu.';
$strShowStatusDelayed_writesDescr = 'INSERT DELAYED ridasid loodud.';
$strShowStatusFlush_commandsDescr  = 'FLUSH kskude arv.';
$strShowStatusHandler_commitDescr = 'Sisemiste COMMIT kskude arv.';
$strShowStatusHandler_deleteDescr = 'Mitu korda rida kustutati tabelist.';
$strShowStatusHandler_discoverDescr = 'MySQLi server vib ksida "NDB Cluster storage engine" (klaster salvestus mootor)  kas ta teab tabelit etteantud nimega. Seda kutsutakse avastus(discovery). Handler_discover annab mitu korda on tabel leitud.';
$strShowStatusHandler_read_firstDescr = 'Mitu korda loeti esimene tulemus indeksist. Kui see on suur, see soovitab et server teeb palju tis indeksi skaneerimist; nitkes, SELECT col1 FROM foo, arvates et col1 indekseeritud.';
$strShowStatusHandler_read_keyDescr = 'Mitu korda loeti rida vtme jrgi. Kui see on suur, see on hea nitaja et sinu pringud ja tabelid on korralikult indekseeritud.';
$strShowStatusHandler_read_nextDescr = 'Mitu korda saadi ksk lugeda vtme jrgi jrgmine rida. See on suurenev kui sa prid indekseeritud piiratud vlja vi sa teed indeksi skaneerimist.';
$strShowStatusHandler_read_prevDescr = 'Mitu korda saadi ksk lugeda vtme jrgi eelnev rida. See lugemise meetod on peamiselt kasutatud optimiseerimiseks ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'Mitu korda saadi ksk lugeda kindel rida. See on suur kui sa teed palju pringuid mis vajavad tulemuse sorteerimist. Sa kasutad kindlasti pringuid mis vajavad MySQLi et skaneerida kogu tabelit vi liited(joins) mis ei kasuta vtmeid korralikult.';
$strShowStatusHandler_read_rnd_nextDescr = 'Mitu korda saadi ksk lugeda jrgmine rida andmefailist. See on suur kui sa teed palju tabeli skaneerimisi. Enamasti see soovitab et sinu tabelid pole korralikult indekseeritud vi sinu pringud pole kirjutatud nii et vtta eeliseid sinu loodud indeksitest.';
$strShowStatusHandler_rollbackDescr = 'Mitu korda kivitati sisemine ROLLBACK lausung.';
$strShowStatusHandler_updateDescr = 'Mitu korda uuendati tabeli rida.';
$strShowStatusHandler_writeDescr = 'Mitu korda lisati uus rida tabelisse.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Mitu leheklge sisaldab andmeid (puhast vi musta).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Mitu leheklge on mustad.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Mitu puhvri leheklge on mratud puhastamisele.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Mitu puu leheklge.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Mitu lukus lehte on InnoDB puhvris. Need lehed on hetkel lugemisel vi kirjutamisel ja pole vimalik puhastada vi kustutada mingil phjusel.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Mitu lehte on hetkel kasutuses kuna nad reserveeritud nagu rea lukustus vi kohanemisvimeline indeks. Seda summat saab ka arvutada nii Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Kogu puhvris suurus, lehtedes.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Mitu InnoDB juhuslikku(random) ette-lugemisi on ts. See juhtub kui pring on skaneerida suur osa tabelist kuid juhuslikus jrjekorras.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Mitu InnoDB jrjestikku ette-lugemisi on ts. See juhtub kui InnoDB teeb jrjestikulist kogu tabeli skaneerimist.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Mitu loogilist lugemist InnoDB on teinud.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Mitu loogilist lugemist InnoDB polnud vimalik puhvris poolt rahuldada ja tegi ksiku lehe lugemise.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Tavaliselt, kirjutab InnoDB puhvri taustal. Kuid, kui vajalik kirjutada leht ja htegi puhast lehte pole saadaval, on vajalik oodata et lehed oleksid enne htlustatud. See This loendur loeb kiki neid ootamisi. Kui puhvri suurus on seatud korralikult, se number peaks olema vike.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Mitu korda kirjutas InnoDB puhvrisse.';
$strShowStatusInnodb_data_fsyncsDescr = 'Mitu fsync() operatsiooni siiani.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Mitu hetkel ootel fsync() operatsiooni.';
$strShowStatusInnodb_data_pending_readsDescr = 'Mitu ootel lugemist.';
$strShowStatusInnodb_data_pending_writesDescr = 'Mitu ootel kirjutamist.';
$strShowStatusInnodb_data_readDescr = 'Suurus kui palju andmeid on loetud siiani, baitides.';
$strShowStatusInnodb_data_readsDescr = 'Mitu korda loetud.';
$strShowStatusInnodb_data_writesDescr = 'Mitu korda andmeid kirjutati.';
$strShowStatusInnodb_data_writtenDescr = 'Suurus palju andmeid on kirjutatud, baitides.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Mitu korda tehti topeltkirjutamist ja mitu lehte on kirjutatud just sellel phjusel.';
$strShowStatusInnodb_dblwr_writesDescr = 'Mitu korda tehti topeltkirjutamise kirjutamist ja mitu lehte on kirjutatud just sellel phjusel.';
$strShowStatusInnodb_log_waitsDescr = 'Mitu ootamist on olnud selleprast et logi puhver oli liiga vike ja pidi ootama enne htlustamist et jtkata.';
$strShowStatusInnodb_log_write_requestsDescr = 'Mitu logi kirjutamise soovi.';
$strShowStatusInnodb_log_writesDescr = 'Mitu fsilist kirjutamist logi faili.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Mitu fsyncs kirjutamist tehtud logi faili.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Mitu ootel logi faili fsyncs.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'ootel logifaili kirjutamisi.';
$strShowStatusInnodb_os_log_writtenDescr = 'Mitu baiti on kirjutatud logi faili.';
$strShowStatusInnodb_pages_createdDescr = 'Lehti loodud.';
$strShowStatusInnodb_page_sizeDescr = 'Sisse-kompileeritud InnoDB lehe suurus (vaikimisi 16KB). Paljud vrtused on loetud lehtedes; lehe suurus lubab neid lihtsalt arvutada baitidesse.';
$strShowStatusInnodb_pages_readDescr = 'Lehti loetud.';
$strShowStatusInnodb_pages_writtenDescr = 'Lehti kirjutatud.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Mitu rea lukustamist on hetkel ootel.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Keskimne aeg prides rea lukustust, millisekundites.';
$strShowStatusInnodb_row_lock_timeDescr = 'Aeg mis on raisatud prides rea lukustust, millisekundites.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Maksimaalne aeg prides rea lukustust, millisekundites.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Mitu korda pidi rea lukustus ootama.';
$strShowStatusInnodb_rows_deletedDescr = 'Mitu rida kustutatud InnoDB tabelitest.';
$strShowStatusInnodb_rows_insertedDescr = 'Mitu rida lisati InnoDB tabelitesse.';
$strShowStatusInnodb_rows_readDescr = 'Mitu rida loetud InnoDB tabelitest.';
$strShowStatusInnodb_rows_updatedDescr = 'Mitu rida uuendati InnoDB tabelites.';
$strShowStatusKey_blocks_not_flushedDescr = 'Mitu vtme plokki on vtme vahemlus muutunud kui pole veel kettale kirjutatud. Tuntud nagu Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Mitu kasutamatta vtme plokki on vtme vahemlus. Sa saad kasutatda seda vrtust et teada saada kui palju vtme vahemlust on kasutuses.';
$strShowStatusKey_blocks_usedDescr = 'Mitu kasutatud plokki on vtme vahemlus. See vrtus nitab maksimaalse plokkide arvu mis on kunagi olnud kasutuses.';
$strShowStatusKey_read_requestsDescr = 'Mitu pringut et lugeda vtme plokk vahemlust.';
$strShowStatusKey_readsDescr = 'Mitu fsilist lugemist lugeda vtme plokk kettalt. kui Key_reads on suur, siis sinu key_buffer_size nitaja on kindlasti vike. Vahemlus mdaminek on vimalik arvutada nii Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Mitu pringut et kirjutada vtme plokk vahemllu.';
$strShowStatusKey_writesDescr = 'Mitu fsilist kirjutamist kirjutada vtme plokk kettale.';
$strShowStatusLast_query_costDescr = 'Viimase kompileeritud pringu arvuatud tulemus pringu optimiseerija vastu. Kasulik vrdlemaks erinevaid pringu plaane helt ja samalt pringult. Vaikimisi vrtus 0 thendab et pring pole veel tdeldud.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Mitu rida on ootel INSERT DELAY pringutes.';
$strShowStatusOpened_tablesDescr = 'Mitu tabelit on avatud. Avatud tabeleid on palju siis sinu tabeli vahemlus kindlasti liiga vike.';
$strShowStatusOpen_filesDescr = 'Mitu faili on avatud.';
$strShowStatusOpen_streamsDescr = 'Mitu voogu on hetkel avatud (enamasti logimiseks).';
$strShowStatusOpen_tablesDescr = 'Mitu tabelit on hetkel avatud.';
$strShowStatusQcache_free_blocksDescr = 'Vabad mlu plokid pringute vahemlus.';
$strShowStatusQcache_free_memoryDescr = 'Vaba mlu pringute vahemlus.';
$strShowStatusQcache_hitsDescr = 'Leitud Puhvrist.';
$strShowStatusQcache_insertsDescr = 'Mitu pringut on lisatud vahemllu.';
$strShowStatusQcache_lowmem_prunesDescr = 'Mitu pringut kustutati puhvrist et vabastada mlu uutele pringutele. See informatsioon aitab sind pringute-puhvri suuruse seadistamisel. Pringute vahemlu kasutab viimati kasutatud strateegiat(LRU) et otsustada millised pringud eemaldada puhvrist.';
$strShowStatusQcache_not_cachedDescr = 'Mitu mitte-puhverdatud pringut (pole salvestatud vahemllu, vi sltuvalt query_cache_type stetest mitte puhverdatud).';
$strShowStatusQcache_queries_in_cacheDescr = 'Mitu pringut on registreeritud vahemlus.';
$strShowStatusQcache_total_blocksDescr = 'Plokkide koguarv pringute vahemlus.';
$strShowStatusReset = 'Nulli';
$strShowStatusRpl_statusDescr = 'See staatus on trkekindel tiraeerimine (failsafe replication) (pole veel kasutuses).';
$strShowStatusSelect_full_joinDescr = 'Liited(joins) mis ei kasuta indekseid. Kui see nitaja on 0, peaksid ettevaatlikult kontrollima oma tabelites indekseid.';
$strShowStatusSelect_full_range_joinDescr = 'Liidete arv mida kasutati piirkonna otsimisel eelistatud tabelist.';
$strShowStatusSelect_range_checkDescr = 'Ilma vtmeta liidete(joins) arv mis konrollivad peale igat rida vtme kasutamist. (Kui see pole 0 siis peaksid ettevaatlikult kontrollima oma tabelite indekseid.)';
$strShowStatusSelect_rangeDescr = 'Liidete arv mida kasutati esimese tabeli piirides. (Pole eriti kriitiline kui see on vga suur.)';
$strShowStatusSelect_scanDescr = 'Liidete arv mis tegid tielikku skaneerimist esimesest tabelist.';
$strShowStatusSlave_open_temp_tablesDescr = 'Ajutiste tabelite arv mis on hetkel avatud alam-limu(replication slave) poolt.';
$strShowStatusSlave_retried_transactionsDescr = 'Kogusumma (alates kivitamisest) mitu korda tiraeerimise(replication) SQL alam-lim(replication slave) proovis lekandeid.';
$strShowStatusSlave_runningDescr = 'Kui see on ON kui serveril on alam server(masin) mis on henduses masteriga.';
$strShowStatusSlow_launch_threadsDescr = 'Limude arv mis vtsid rohkem aega kivitamiseks kui slow_launch_time.';
$strShowStatusSlow_queriesDescr = 'Pringute arv mis vtsid rohkem aega kui long_query_time sekundites.';
$strShowStatusSort_merge_passesDescr = 'Edukate hinemiste(merge) arv millega lhike algoritm on tegelenud. Kui see vrtuse on suur, sa peaksid mtlema sort_buffer_size vrtuse suurendamist.';
$strShowStatusSort_rangeDescr = 'Sorteerimiste arv mis on tehtud piirkonna ulatuses.';
$strShowStatusSort_rowsDescr = 'Sorteritud ridade arv.';
$strShowStatusSort_scanDescr = 'Sorteerimiste arv mis on tehtud tabeli skaneerimist kasutades.';
$strShowStatusTable_locks_immediateDescr = 'Mitu korda tabeli lukustus justus koheselt.';
$strShowStatusTable_locks_waitedDescr = 'Mitu korda tabeli lukustus ei justunud koheselt ja pandi ootele. Kui see on suur ja judlusega on probleeme, sa peaksid optimiseerima oma pringuid vi poolitama oma tabelid vi kasutama tiraeerimist(replication).';
$strShowStatusThreads_cachedDescr = 'Limude arv Limude vahemlus. Vahemlu kasutamist(hit) on vimalik arvutada nii Threads_created/Connections. Kui see on punane paksid suurendama thread_cache_size suurust.';
$strShowStatusThreads_connectedDescr = 'Hetkel avatud hendusi.';
$strShowStatusThreads_createdDescr = 'Limude arv mis on loodud henduste haldamiseks. Kui Threads_created on suur siis suurenda thread_cache_size vrtust. (Tavaliselt see ei anna mrgatavat kiiruse tusu kui Limude teostus on korralik.)';
$strShowStatusThreads_runningDescr = 'Limude arv mis mis hetkel ei maga.';
$strShowTableDimension = 'Nita tabelite dimensiooni';
$strShowTables = 'Nita tabeleid';
$strShowThisQuery = ' Nita pringut siin uuesti ';
$strSimplifiedChinese = 'Lihtsustatud Hiina';
$strSingly = '(ksikult)';
$strSize = 'Suurus';
$strSkipQueries = 'Kske (pringuid) mida algusest vahele jtta';
$strSlovak = 'Slovaki';
$strSlovenian = 'Sloveenia';
$strSmallBigAll = 'Kik Vikeseks/Suureks';  
$strSocketProblem = '(vi kohaliku MySQL serveri soketid ei ole korrektselt seadistatud)';
$strSortByKey = 'Sorteeri vtme jrgi';
$strSorting = 'Jrjestamine';
$strSort = 'Sorteeri';
$strSpaceUsage = 'Ruumivtt';
$strSpanish = 'Hispaania';
$strSplitWordsWithSpace = 'Snad on eraldatud thikuga (" ").';
$strSQLCompatibility = 'SQL hilduvus viis';
$strSQLExportType = 'Ekspordi tp';
$strSQLImportOptions = 'SQL seaded';
$strSQLOptions = 'SQL seaded';
$strSQLParserBugMessage = 'On vimalus, et te leidsite vea SQL parseris. Palun kontrollige oma pringut tpsemalt ja kontrollige, et jutumrgid/lakomad oleks korrektselt lpetatud. Veel on vimalik, et te loete sisse faili kus on binaarne info vljaspool varjestatud tekstiala. Samuti viksite te proovida oma pringut MySQLi ksureal. MySQLi viga vljastatakse pringu all, kui seal testi on mni viga, siis see vib aidata teil leida vea algphjuseid. Kui teil on peale seda ikka veel probleeme vi kui mu parser keeldub ttamast ning MySQL ksurida ttab, siis palun vhendage oma pringuid ksiku pringuni, mis phjustab probleeme ja sisestage vea raport koos viga phjustanud pringuga LIGET sektsioonis allpool:';
$strSQLParserUserError = 'Tundub, et teie SQL pringus on viga. MySQLi serveri error peaks ilmuma allpool, kui seal on midagi, siis peaks see teil aitama leia vea phjust.';
$strSQLQuery = 'SQL-pring';
$strSQLResult = 'SQL tulemus';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Vigane identifikaator';
$strSQPBugUnclosedQuote = 'Sulgemata jutumrk/lakoma';
$strSQPBugUnknownPunctuation = 'Tundmatu suunav tekst';
$strStandInStructureForView = 'Sise-vaate struktuur';
$strStatCheckTime = 'Viimane vaatamine';
$strStatCreateTime = 'Loodud';
$strStatement = 'Parameerid';
$strStatisticsOverrun = 'Koormusega serveris, baitide lugeja vib lugeda vigadega (overrun), st. see statistika mida nitab MySQL server ei pruugi olla tpne.';
$strStatUpdateTime = 'Viimane muudatus';
$strStatus = 'Staatus';
$strStorageEngines = 'Varundusmootorid';
$strStorageEngine = 'Varundusmootor';
$strStrucCSV = 'CSV andmed';
$strStrucData = 'Struktuur ja andmed';
$strStrucExcelCSV = 'CSV MS Exceli jaoks';
$strStrucNativeExcel = 'Loomulikud MS Exceli andmed';
$strStrucNativeExcelOptions = 'Plised Exceli eksportimise seaded';
$strStrucOnly = 'Ainult struktuur';
$strStructPropose = 'Soovita tabeli struktuuri';
$strStructureForView = 'Vaate (view) struktuur';  
$strStructure = 'Struktuur';
$strSubmit = 'Vali';
$strSuccess = 'Teie SQL pring tideti edukalt';
$strSum = 'Summa';
$strSwedish = 'Rootsi';
$strSwitchToDatabase = 'Mine kopeeritud andmebaasile';
$strSwitchToTable = 'Mine le kopeeritud tabelile';

$strTableAlreadyExists = 'tabel %s on juba olemas!';
$strTableComments = 'Tabeli kommentaarid';
$strTableEmpty = 'Tabeli nimi on thi!';
$strTableHasBeenDropped = 'Tabel %s kustutatud';
$strTableHasBeenEmptied = 'Tabel %s thjendatud';
$strTableHasBeenFlushed = 'Tabel %s htlustatud';
$strTableIsEmpty = 'Tabel tundub olevat thi!';  
$strTableMaintenance = 'Tabeli hooldus';
$strTableName = 'Tabeli nimi';  
$strTableOfContents = 'Sisukord';
$strTableOptions = 'Tabeli seaded';
$strTables = '%s tabel(it)';
$strTableStructure = 'Struktuur tabelile';
$strTable = 'Tabel';
$strTakeIt = 'vta see';
$strTblPrivileges = 'Tabel-spetsiifilised privileegid';
$strTempData = 'Ajutised andmed ';
$strTextAreaLength = ' Oma suuruse tttu<br /> vib see vli olla mittemuudetav ';
$strThai = 'Tai';
$strThemeDefaultNotFound = 'Ei leia vaikimisi teemat %s!';
$strThemeNoPreviewAvailable = 'Eelvaade pole saadaval.';
$strThemeNotFound = 'Ei leia teemat %s!';
$strThemeNoValidImgPath = 'Ei leia pildi kataloogi teemale %s!';
$strThemePathNotFound = 'Ei leia kataloogi teemale %s!';
$strTheme = 'Teema / Stiil';
$strThisHost = 'Antud host';
$strThreads = 'Limud';
$strThreadSuccessfullyKilled = 'Protsess %s katkestati edukalt.';
$strTime = 'Aeg';
$strTimeoutInfo = 'Eelmine Import aegus, peale uuesti postitamist jtkub asukohast %d.';
$strTimeoutNothingParsed = 'Kuigi viimasel laadimisel andmeid ei tdeldud, see thendab enamasti et phpMyAdmin pole vimeline Importi lpetama, kui sa php skripti aega ei pikenda.';
$strTimeoutPassed = 'Skripti ajalimiit on letatud, kui soovid importimist jtkata, palun lae sama fail uuesti ja import jtkub.';
$strToFromPage = 'Kuhu/Kust leht';  
$strToggleScratchboard = 'vaheta mrkmetahvlit';
$strToSelectRelation = 'Et valida suhe, kliki :';
$strTotal = 'kokku';
$strTotalUC = 'Kokku';
$strTraditionalChinese = 'Traditsionaalne Hiina';
$strTraditionalSpanish = 'Traditsionaalne Hispaania';
$strTraffic = 'Liiklus';
$strTransactionCoordinator = 'lekande kordinaator';
$strTransformation_application_octetstream__download = 'Nita linki millega laadida alla vlja binaarne info. Esimene seade on binaarse faili nimi. Teine seade on vimalik vljanimi tabelis mis sisaldab failinime. Kui te mrate teise seade siis peab esimene seade olema thi tekst';
$strTransformation_application_octetstream__hex = 'Kuvab andmed kuueteistkmnend ssteemis. Valikuline Esimene parameeter seab kui tihti ruumi tehakse (vaikimisi 2 nkkamist).';
$strTransformation_image_jpeg__inline = 'Kuvab lingitud vikepildi; seaded: laius,krgus pikslites (hoiab alles originaalpildi laiuse-krguse suhte)';
$strTransformation_image_jpeg__link = 'Kuvab lingi sellele pildile (otsene binaarne allalaadimine, jne.).';
$strTransformation_image_png__inline = 'Vaata image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Nitab TIME, TIMESTAMP, DATETIME vi numbrilist unixi ajatempli vlja formaaditud kuupevana. Esimene valik on ajanihe (tundides) mis lisatakse ajatemplile (Vaikimisi: 0). Kasuta teist valikut et tpsustada kuupeva formaat. Kolmas valik annab valida kas kuupev kasutab kohalikku aega vi UTC oma (kasuta "local" (kohalik) vi "utc" stringe). Sellest tulenevalt, kuupeva formaadil on teine vrtus - "local" vrtuse tpsustamiseks vaata dokumentatsiooni PHP strftime() funktsiooni kasutamise kohta ja  kasutades "utc" vaata gmdate() funtsiooni kasutamist.'; 
$strTransformation_text_plain__external = 'AINULT LINUXILE: Kivitab vlise aplikatsiooni ja annab talle standard sisendisse ette vlja sisu. Tagastab aplikatsiooni standard vljundi. Vaikimisi on selleks Tidy, et kuvada ilusti formaaditud HTML koodi. Turvariskide maandamiseks peate te ksitsi muutma faili libraries/transformations/text_plain__external.inc.php ja lisama sinna programmid mida te lasete kivitada. Esimene seade on siis kasutatava programmi number, teine seade on programmi parameetrid. Kui kolmas seade on 1 siis tdeldakse vljund funktsiooniga htmlspecialchars() (vaikimisi 1). Kui neljas seade on  1 pannakse NOWRAP sisu lahtrile nii, et kogu vljund kuvatakse ilma formaati muutmata(vaikimisi 1)';
$strTransformation_text_plain__formatted = 'Hoiab alles originaalset vlja formaati. Ei varjestata.';
$strTransformation_text_plain__imagelink = 'Kuvab pildi ja lingi, vli sisaldab failinime; esimene seade on eelnev tekst nagu "http://domain.com/", teine seade on laius pikslites, kolmas on krgus.';
$strTransformation_text_plain__link = 'Kuvab lingi, vli sisaldab failinime; esimene seade on eelnev tekst niteks "http://domain.com/", teine seade on nimi lingile.';
$strTransformation_text_plain__sql = 'Vormib SQL pringu tekstiks esile tstetuna.';
$strTransformation_text_plain__substr = 'Nitab ainult osa tekstist. Esimene seade on mrang kust positsioonilt teie teksti kuva hakkab.(vaikimisi 0). Teine seade on kuipalju teksti tagastatakse, kui see thjaks jtta, tagastatakse kogu allesjnud tekst. Kolmas seade defineerib mis tekst lisatakse vljundi lppu kui saadud tekst tagastatakse. (vaikimisi: ...) .';
$strTruncateQueries = 'Lhenda nidatavad pringud';
$strTurkish = 'Trgi';
$strType = 'Tp';

$strUkrainian = 'Ukraina';
$strUncheckAll = 'Puhasta kik';
$strUnicode = 'Unikaalne';
$strUnique = 'Unikaalne';
$strUnknown = 'tundmatu';
$strUnselectAll = 'Puhasta kik';
$strUnsupportedCompressionDetected = 'Proovisid laadida faili tundmatu pakkimisega (%s). Vimalik et toetus ei ole veel lisatud vi on sinu seadetes keelatud.';
$strUpdatePrivMessage = 'Te uuendasite privileege %s-l.';
$strUpdateProfileMessage = 'Profiil uuendatud.';
$strUpdateQuery = 'Uuenda pringut';
$strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';
$strUpgrade = 'Te peaksite uuendama %s -i versioonini %s vi uuemaks.';
$strUploadLimit = 'Te kindlasti proovisite laadida liiga suurt faili. Palun uuri dokumentatsiooni %sdocumentation%s selle limiidi seadmiseks.';
$strUploadsNotAllowed = 'Faile pole lubatud laadida sellesse serverisse.';  
$strUsage = 'Kasutus';
$strUseBackquotes = 'Kasutage tagurpidi kaldkriipse tabelites vi tabelinimedes';
$strUsedPhpExtensions = 'Kasutatud PHP laiendid';
$strUseHostTable = 'Kasuta host tabelit';
$strUserAlreadyExists = 'Kasutaja %s on juba olemas!';
$strUserEmpty = 'Kasutajanimi on thi!';
$strUser = 'Kasutaja';
$strUserName = 'Kasutajanimi';
$strUserNotFound = 'Valitud kasutajat ei leitud privileegide tabelist.';
$strUserOverview = 'Kasutaja levaade';
$strUsersDeleted = 'Valitud kasutajad on nnestunult kustutatud.';
$strUsersHavingAccessToDb = 'Kasutajad kellel on ligips &quot;%s&quot;';
$strUseTabKey = 'Kasutage TAB klahvi, et liikuda helt vrtuselt teisele vi CTRL+nool, et liikuda noole suunas';
$strUseTables = 'Kasuta tabeleid';
$strUseTextField = 'Kasutage tekstivlja';
$strUseThisValue = 'Kasuta seda vrtust';

$strValidateSQL = 'Kontrolli SQL-i';
$strValidatorError = 'SQL-i valideerijat ei suudetud avada. Palun kontrollige, et te olete installinud vastavad php moodulid nagu on kirjeldatud %sdokumentatsioonis%s.';
$strValue = 'Vrtus';
$strVar = 'Muutuja';
$strVersionInformation = 'Versiooni info';
$strViewDumpDatabases = 'Nita andmebaaside sisu (skeemi)';
$strViewDumpDB = 'Vaata andmebaasi vljundit (skeemi)';
$strViewDump = 'Vaata tabeli vljundit (skeemi)';
$strViewHasBeenDropped = 'Vaade %s on kustutatud';
$strViewMaxExactCount = 'Sellel vaatel on rohkem kui %s rida. Palun vaata %sdocumentation%s.';
$strView = 'Vaade';

$strWebServerUploadDirectoryError = 'Kataloog mille Te leslaadimiseks sttisite ei ole ligipsetav';
$strWebServerUploadDirectory = 'webiserveri leslaadimiskataloogi';
$strWelcome = 'Tere tulemast %s';
$strWestEuropean = 'Lne-Euroopa';
$strWildcard = 'metamrk';
$strWindowNotFound = 'Vajaliku sirvija akent ei suudetud uuendada. Vibolla Te olete peaakna sulgenud vi Teie sirvija ei luba akendevahelist suhtlist tnu turvaseadetele.';
$strWithChecked = 'Valitud:';
$strWriteRequests = 'Prdumised kirjutamiseks';
$strWrongUser = 'Vale kasutajanimi/parool. Ligips keelatud.';

$strXMLOptions = 'XML seaded';  
$strXML = 'XML';

$strYes = 'Jah';

$strZeroRemovesTheLimit = 'Mrkus: Mrkides antud seaded 0 (null), eemaldate limiidi.';
$strZip = '"zipitud"';

// To translate:

$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate

$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate

$strToggleSmallBig = 'Toggle small/big';  //to translate

$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
